@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
 
-from collections import Counter, OrderedDict
 from enum import Enum, EnumMeta, unique, _is_dunder as ispyname
 from functools import wraps
 
@@ -39,17 +38,6 @@ if PY3:
     unicode = str
     long = int
 
-try:
-    from collections.abc import (Mapping, MutableMapping,
-                                 Hashable as HashableABC,
-                                 Sequence as SequenceABC,
-                                 Sized as SizedABC)
-except (ImportError, SyntaxError):
-    from collections import (Mapping, MutableMapping,
-                             Hashable as HashableABC,
-                             Sequence as SequenceABC,
-                             Sized as SizedABC)
-
 try:
     from importlib.util import cache_from_source
 except (ImportError, SyntaxError):
@@ -76,11 +64,6 @@ except (ImportError, SyntaxError):
     except (ImportError, SyntaxError):
         Path = None
 
-try:
-    from scandir import scandir, walk
-except ImportError:
-    from os import scandir, walk
-
 try:
     import numpy
 except (ImportError, SyntaxError):
@@ -91,16 +74,13 @@ try:
 except (ImportError, SyntaxError):
     pass
 
-__all__ = ('Counter', 'OrderedDict',
-           'Enum', 'EnumMeta', 'unique',
+__all__ = ('Enum', 'EnumMeta', 'unique',
            'ispyname', 'pytuple',
            'AutoType', 'auto',
            'unicode', 'long',
-           'Mapping', 'MutableMapping',
-           'HashableABC', 'SequenceABC', 'SizedABC',
            'cache_from_source',
            'lru_cache',
-           'Path', 'scandir', 'walk',
+           'Path',
            'numpy',
            'reduce')
 
