@@ -33,10 +33,10 @@ def itermodule(module):
         contained in a given module (although it’ll probably work
         for classes and instances too – anything `dir()`-able.)
     """
-    keys = tuple(key for key in sorted(dir(module)) \
+    keys = tuple(key for key in dir(module) \
                       if key not in BUILTINS)
     values = (getattr(module, key) for key in keys)
-    return zip(keys, values)
+    yield from zip(keys, values)
 
 def moduleids(module):
     """ Get a dictionary of `(name, thing)` tuples from a module,
@@ -55,7 +55,7 @@ def itermoduleids(module):
     keys = tuple(key for key in dir(module) \
                       if key not in BUILTINS)
     ids = (id(getattr(module, key)) for key in keys)
-    return zip(keys, ids)
+    yield from zip(keys, ids)
 
 # This goes against all logic and reason, but it fucking seems
 # to fix the problem of constants, etc showing up erroneously
@@ -258,8 +258,8 @@ class Registry(abc.ABC, metaclass=clu.abstract.Slotted):
     
     @staticmethod
     def all_appnames():
-        """ Return a tuple of all registered appnames """
-        return sorted(appnames)
+        """ Return a generator over all currently registered appnames """
+        yield from sorted(appnames)
     
     @staticmethod
     def for_appname(appname):
@@ -394,23 +394,19 @@ class ExporterBase(collections.abc.MutableMapping,
     
     @classmethod
     def modulenames(cls):
-        """ Get a sorted list of module names – the keys to the Exporter
-            instance registry – that are currently available
+        """ Get a generator yielding from a sorted list of module names
+            – keys to the Exporter instance registry – currently available
         """
-        return sorted(cls.instances.keys())
+        yield from sorted(cls.instances.keys())
     
     @classmethod
     def modules(cls):
-        """ Get a dict of actual modules corresponding to the
+        """ Get a dictionary of actual modules corresponding to the
             currently registered Exporter instances
         """
-        modulenames = cls.modulenames()
-        mods = []
-        
-        for modulename in modulenames:
-            mods.append(importlib.import_module(modulename))
-        
-        return dict(zip(modulenames, mods))
+        return { modulename : importlib.import_module(modulename) \
+                                                  for modulename \
+                                               in cls.modulenames() }
     
     @classmethod
     def nameof(cls, thing):
