@@ -74,9 +74,21 @@ class MetaRegistry(Extensible):
         if not appname:
             raise ValueError("appname required")
         if not isstring(appname):
-            raise TypeError("module registry access by string keys only")
+            raise TypeError("module registry access by strings only")
         return Registry.monomers[appname]
     
+    @staticmethod
+    def for_qualname(qualname):
+        if not qualname:
+            raise ValueError("qualname required")
+        if not isstring(qualname):
+            raise TypeError("module registry access by strings only")
+        if not consts.QUALIFIER in qualname:
+            raise ValueError("qualname isn’t qualified")
+        modulename, appnamespace = dotpath_split(qualname)
+        appname, _, appspace = appnamespace.partition(consts.QUALIFIER)
+        return Registry.for_appname(appname)[qualname]
+    
     def __getitem__(cls, key):
         """ Allows lookup of an app name through subscripting the Registry class """
         return Registry.for_appname(key)
@@ -105,20 +117,29 @@ class MetaRegistry(Extensible):
 
 @export
 def all_registered_appnames():
-    """ Return a tuple of strings, listing all registered app names """
-    return tuple(sorted(Registry.monomers.keys()))
+    """ Return a generator of strings listing all registered app names """
+    yield from sorted(Registry.monomers.keys())
 
 @export
 def all_registered_modules():
-    """ Return a tuple filled with instances of all registered class-based modules """
-    return tuple(iterchain(modules.values() for modules in Registry.monomers.values()))
+    """ Return a generator over the instances of all registered class-based modules """
+    yield from iterchain(modules.values() for modules in Registry.monomers.values())
 
 @export
 def modules_for_appname(appname):
-    """ Return a tuple filled with instances of an apps’ registered class-based modules """
-    if appname not in Registry.monomers:
-        return tuple()
-    return tuple(Registry.monomers[appname].values())
+    """ Return a generator over the instances of an apps’ registered class-based modules """
+    # N.B. iterating this particular generator can sometimes trigger
+    # garbage-collection of class-based module subtypes that are 
+    # in the monomer cache, but not in “sys.modules” – that’s why
+    # we’re trapping RuntimeErrors here, as that’s what gets raised
+    # when e.g. the monomer cache resizes during iteration, due to
+    # garbage collection nullifying one or more of the weakrefs that
+    # comprise said cache.
+    modules = Registry.monomers.get(appname, {})
+    try:
+        yield from modules.values()
+    except RuntimeError:
+        yield from modules.values()
 
 @export
 class Registry(abc.ABC, metaclass=MetaRegistry):
@@ -335,6 +356,10 @@ class LoaderBase(clu.abstract.AppName,
             else:
                 module._executed = True
     
+    def __reduce__(self):
+        return (polymers.get_loader,
+                tuplize(type(self).appname))
+    
     def __repr__(self):
         qualname = qualified_name(self)
         appname = getattr(self, 'appname', None)
@@ -553,6 +578,11 @@ class ModuleBase(Package, Registry, metaclass=MetaModule):
         return dotpath_join(self.prefix,
                             self.name)
     
+    def __reduce__(self):
+        return (Registry.for_qualname,
+                tuplize(self.qualname),
+                        self.__dict__)
+    
     def __dir__(self):
         cls = type(self)
         if hasattr(cls, 'exporter'):
@@ -577,8 +607,8 @@ class PerApp:
     appname: str                         = field(default_factory=str)
     
     def appspaces(self):
-        """ Return a tuple with this app’s defined appspaces """
-        return tuple(self.modules.keys())
+        """ Return a generator over this app’s defined appspaces """
+        yield from self.modules.keys()
     
     def __repr__(self):
         return stringify(self,
@@ -621,6 +651,16 @@ class PolymerType(dict):
             raise NameError(f"module already exists in “{appname}” for appspace: {appspace}")
         self[appname].modules.update({ appspace : module })
         return self[appname]
+    
+    def get_finder(self, appname):
+        if not self.get(appname, None):
+            raise ValueError(f"no PerApp instance for appname: {appname}")
+        return self[appname].finder
+    
+    def get_loader(self, appname):
+        if not self.get(appname, None):
+            raise ValueError(f"no PerApp instance for appname: {appname}")
+        return self[appname].loader
 
 # The per-appname subtype registry dictionary:
 polymers = PolymerType()
@@ -735,8 +775,10 @@ class ChainModuleMap(clu.dicts.ChainMap):
         # Use “item_search(…)” in order to only trigger a constituent
         # maps’ “__missing__(…)” method within our own “__missing__(…)”
         # function call:
-        return item_search(key, *self.maps, default=None) \
-            or self.__missing__(key)
+        item = item_search(key, *self.maps, default=NoDefault)
+        if item is NoDefault:
+            return self.__missing__(key)
+        return item
     
     def __missing__(self, key):
         # “self.fallbacks” should be populated with any module-level
@@ -751,10 +793,6 @@ class ChainModuleMap(clu.dicts.ChainMap):
         if key in self:
             return 0
         raise KeyError(key)
-    
-    def inner_repr(self):
-        from pprint import pformat
-        return pformat(dict(zip(self, (self[item] for item in self))))
 
 # Define an out-of-line target-processing function:
 def add_targets(instance, *targets):
@@ -1012,17 +1050,19 @@ def test():
         assert o
         assert d
         assert O
+        
+        # from clu.app import DerivedModule as dd
     
     @inline
     def test_three():
         """ Class-module registry basics """
         
         print("all_registered_appnames():")
-        pprint(all_registered_appnames())
+        pprint(tuple(all_registered_appnames()))
         print()
         
         print("all_registered_modules():")
-        pprint(all_registered_modules())
+        pprint(tuple(all_registered_modules()))
         print()
         
         m = Module(consts.PROJECT_NAME)
@@ -1059,10 +1099,10 @@ def test():
         assert spec0.name == 'clu.app.FindMe'
         
         module0 = finder.loader.create_module(spec0)
-        assert isinstance(module0, Module)
+        assert isinstance(module0, (FindMe, Module))
         
         module1 = finder.loader.create_module(spec0)
-        assert isinstance(module1, Module)
+        assert isinstance(module1, (FindMe, Module))
         
         spec1 = finder.find_spec('clu.app.FindMe', [])
         assert spec1.name == 'clu.app.FindMe'
@@ -1193,9 +1233,7 @@ def test():
     def test_six_point_five():
         """ “PerApp” dataclass and module cache check """
         
-        appnames = all_registered_appnames()
-        
-        for appname in appnames:
+        for appname in all_registered_appnames():
             
             assert appname in polymers
             assert appname in monomers
@@ -1241,7 +1279,7 @@ def test():
     @inline.diagnostic
     def show_monomers():
         """ Show all registered Module subclasses """
-        appnames = all_registered_appnames()
+        appnames = tuple(all_registered_appnames())
         appcount = len(appnames)
         plural = (appcount == 1) and "app" or "apps"
         print(f"MONOMERS ({appcount} {plural} total):")
@@ -1258,7 +1296,7 @@ def test():
     @inline.diagnostic
     def show_polymers():
         """ Show per-app class-module-related subclasses """
-        appnames = all_registered_appnames()
+        appnames = tuple(all_registered_appnames())
         appcount = len(appnames)
         plural = (appcount == 1) and "app" or "apps"
         print(f"POLYMERS ({appcount} {plural} total):")
