@@ -6,7 +6,6 @@ import colorama
 colorama.init()
 
 import inspect
-import math
 import sys
 import textwrap
 import zict
@@ -347,17 +346,7 @@ def print_ansi_centered(text, color='',
     """ print_ansi_centered(…) → Print a string to the terminal, centered
                                  and bookended with asterisks """
     message = f" {text.strip()} "
-    asterisks = math.floor((width / 2) - (len(message) / 2))
-    fill = filler[0]
-    
-    aa = fill * asterisks
-    ab = fill * (asterisks + ((width % 2) - (len(message) % 2)))
-    
-    if len(f"{aa}{message}{ab}") < width:
-        aa += fill
-        ab += fill
-    
-    print_ansi(f"{aa}{message}{ab}", color=color)
+    print_ansi(message.center(width, filler), color=color)
 
 INITIAL     = '  ¶ '
 SUBSEQUENT  = '    '
