@@ -7,10 +7,12 @@ from clu.constants.consts import (BASEPATH,
                                   DELETE_FLAG,
                                   DYNAMIC_MODULE_PREFIX,
                                   ENCODING,
+                                  ENVIRONS_SEP,
                                   FILE_ARGUMENT_NAMES,
                                   HOSTNAME,
                                   LAMBDA, λ,
                                   MAXINT,
+                                  NAMESPACE_SEP,
                                   PATH,
                                   PARTIAL, φ,
                                   PROJECT_NAME, PROJECT_PATH,
@@ -43,8 +45,8 @@ from clu.constants.polyfills import (Enum, EnumMeta, unique,
                                      AutoType, auto,
                                      Path, reduce)
 
-from clu.compilation import (Macro, Macros,
-                             CDBSubBase, CDBBase, CDBJsonFile)
+from clu.compilation.macros import Macro, Macros
+from clu.compilation.compiledb import CDBSubBase, CDBBase, CDBJsonFile
 
 from clu.exporting import (itermodule, moduleids, itermoduleids,
                            search_by_id,
@@ -115,7 +117,7 @@ from clu.predicates import (negate, reverse,
 from clu.typespace import types, modulize
 from clu.typespace.namespace import NamespaceRepr, SimpleNamespace, Namespace, isnamespace
 
-from clu.typology import (samelength, differentlength, isunique,
+from clu.typology import (samelength, differentlength, isunique, iterlen,
                           istypelist, ismetatypelist, maketypelist, makemetatypelist,
                           isderivative, subclasscheck, metaclasscheck, graceful_issubclass,
                           numeric_types, array_types, scalar_types, string_types, bytes_types,
@@ -147,14 +149,13 @@ from clu.naming import (determine_module, nameof, moduleof,
 
 from clu.abstract import Cloneable, ReprWrapper
 
-# from clu.config.base import Flat, Nested
+from clu.config.abc import FrozenKeyMap, KeyMap, NamespaceWalker
 from clu.config.abc import FlatOrderedSet, functional_and, functional_set
-from clu.config.defg import (NAMESPACE_SEP, FrozenKeyMap, KeyMap, FrozenFlat, Flat,
-                                                                  FrozenNested, Nested)
-from clu.config.defg import nestedmaps, flatdict
+from clu.config.keymap import FrozenFlat, Flat, FrozenNested, Nested
+from clu.config.keymap import nestedmaps, flatdict
 from clu.config.proxy import KeyMapView, KeyMapProxy
 
-from clu.config.env import Env
+from clu.config.base import Env
 from clu.config.filebase import FileName, FileBase
 from clu.config.fieldtypes import ValidationError
 from clu.config.fieldtypes import FieldBase
@@ -268,10 +269,12 @@ __all__ = ('Image',
            'DELETE_FLAG',
            'DYNAMIC_MODULE_PREFIX',
            'ENCODING',
+           'ENVIRONS_SEP',
            'FILE_ARGUMENT_NAMES',
            'HOSTNAME',
            'LAMBDA', 'λ',
            'MAXINT',
+           'NAMESPACE_SEP',
            'PATH',
            'PARTIAL', 'φ',
            'PROJECT_NAME', 'PROJECT_PATH',
@@ -363,7 +366,7 @@ __all__ = ('Image',
            'allof', 'anyof', 'noneof',
            'types', 'modulize',
            'NamespaceRepr', 'SimpleNamespace', 'Namespace', 'isnamespace',
-           'samelength', 'differentlength', 'isunique',
+           'samelength', 'differentlength', 'isunique', 'iterlen',
            'istypelist', 'ismetatypelist', 'maketypelist', 'makemetatypelist',
            'isderivative', 'subclasscheck', 'metaclasscheck', 'graceful_issubclass',
            'numeric_types', 'array_types', 'scalar_types', 'string_types', 'bytes_types',
@@ -390,8 +393,8 @@ __all__ = ('Image',
            'qualified_import', 'qualified_name_tuple', 'qualified_name',
            'dotpath_to_prefix', 'path_to_prefix',
            'split_abbreviations',
-           'NAMESPACE_SEP', 'Cloneable', 'ReprWrapper', 'FlatOrderedSet',
-           'FrozenKeyMap', 'KeyMap',
+           'Cloneable', 'ReprWrapper', 'FlatOrderedSet',
+           'FrozenKeyMap', 'KeyMap', 'NamespaceWalker',
            'FrozenFlat', 'FrozenNested',
            'KeyMapView', 'KeyMapProxy',
            'Flat', 'Nested',
