@@ -5,10 +5,9 @@ from reprlib import Repr
 import clu.abstract
 import collections.abc
 import contextlib
-import re
 import sys
 
-from clu.constants.consts import pytuple, NoDefault
+from clu.constants.consts import STRINGPAIR, WHITESPACE, pytuple, NoDefault
 from clu.constants.polyfills import ispyname
 from clu.dicts import merge_fast_two, asdict
 from clu.predicates import ismergeable
@@ -19,9 +18,6 @@ export = exporter.decorator()
 
 # NAMESPACES: bespoke “reprlib” recursion-friendly repr-helper:
 
-WHITESPACE = re.compile(r'\s+')
-STRINGPAIR = "{!s} : {!s}"
-
 @export
 class NamespaceRepr(Repr):
     
@@ -185,6 +181,10 @@ class Namespace(BaseNamespace,
         
         Since it implements a `get(…)` method, Namespace instances can be passed
         to `merge(…)` – q.v. `merge(…)` function definition supra.
+        
+        The Namespace class also furnishes a `__missing__(…)` method, which can
+        be overridden by subclasses to provide “collections.defaultdict”–like
+        behaviors.
     """
     
     def get(self, key, default=NoDefault):
@@ -225,7 +225,10 @@ class Namespace(BaseNamespace,
         return exc_type is None
     
     def __getitem__(self, key):
-        return self.__dict__.__getitem__(key)
+        try:
+            return self.__dict__.__getitem__(key)
+        except KeyError:
+            return self.__missing__(key)
     
     def __setitem__(self, key, value):
         self.__dict__.__setitem__(key, value)
@@ -233,6 +236,9 @@ class Namespace(BaseNamespace,
     def __delitem__(self, key):
         self.__dict__.__delitem__(key)
     
+    def __missing__(self, key):
+        raise KeyError(key)
+    
     def __add__(self, operand):
         # On add, old values are not overwritten
         if not ismergeable(operand):
@@ -328,6 +334,24 @@ def test():
         assert dir(sn) == ['i_heard', 'nested', 'so', 'yo']
         assert chop_instance_repr(reprizer.fullrepr(sn, short=True)) == shorty_repr()
     
+    class NamespaceKeyError(KeyError):
+        pass
+    
+    @inline
+    def test_three():
+        """ Namespace subclass “__missing__(…)” check """
+        
+        class MissingNamespace(Namespace):
+            
+            def __missing__(self, key):
+                """ Raise a bespoke exception on missing key access """
+                raise NamespaceKeyError(key)
+        
+        try:
+            MissingNamespace()['wat']
+        except NamespaceKeyError as exc:
+            assert bool(exc)
+    
     return inline.test(100)
 
 if __name__ == '__main__':
