@@ -6,43 +6,48 @@ import pytest
 class TestDicts(object):
     
     """ Run the tests for merging dicts (the clu.dicts module), and
-        namespaces (the clu.typespace and clu.typespace.namespace modules).
+        ChainMaps (both “clu.dicts.ChainMap” and the stdlib version)
     """
     
-    def test_chainmap(self, dirname, environment):
-        from clu.dicts import ChainMap
-        # from clu.predicates import getitem, try_items
-        
-        # READ-ONLY:
-        data = dirname.subdirectory('data')
-        
-        # Arbitrary:
-        dict_one = {
+    @pytest.fixture
+    def arbitrary(self):
+        """ Fixture function providing an arbitrary flat directory """
+        yield {
             'yo'    : "dogg",
             'i'     : "heard",
             'you'   : "liked",
-            'dict'  : "chains" }
+            'dict'  : "chains"
+        }
+    
+    @pytest.fixture
+    def fsdata(self, dirname):
+        """ Return the “data” subdirectory of the “tests” directory """
+        yield dirname.subdirectory('data')
+    
+    def test_chainmap(self, arbitrary, fsdata, environment):
+        """ clu.dicts.ChainMap basic training """
+        from clu.dicts import ChainMap
         
         # Create a ChainMap from a dict, a Directory instance,
         # and an environment mapping:
-        hey = ChainMap(dict_one, data, environment)
+        hey = ChainMap(arbitrary, fsdata, environment)
         
         # Check length and boolean value:
-        assert len(hey) == len(dict_one) + len(data) + len(environment)
+        assert len(hey) == len(arbitrary) + len(fsdata) + len(environment)
         assert bool(hey)
         
         # Check keys from respective sub-maps:
         for key in ('yo', 'i', 'you', 'dict'):
             assert key in hey
-            assert hey.mapcontaining(key) == dict_one
-            assert hey.get(key) == dict_one.get(key)
+            assert hey.mapcontaining(key) == arbitrary
+            assert hey.get(key) == arbitrary.get(key)
         
         for key in ('config', 'yodata', 'yodogg',
                     '8ba.png', '3472236406_1fbf1a567d_o.jpg', 'shutterstock_90194617.jpg',
                     'IMG_20180505_205153567.jpg', '3471426989_aa8e83cac5_o.jpg'):
             assert key in hey
-            assert hey.mapcontaining(key) == data
-            assert hey.get(key) == data.get(key)
+            assert hey.mapcontaining(key) == fsdata
+            assert hey.get(key) == fsdata.get(key)
         
         for key in ('SHELL', 'LESS', 'HOME', 'LANG'):
             assert key in hey
@@ -127,12 +132,91 @@ class TestDicts(object):
         '''
         
         # ONE LAST CHECK. And we’ll call it a day.
-        been = ChainMap(dict_one, data, environment)
+        been = ChainMap(arbitrary, fsdata, environment)
         assert frozenset(buthey).issuperset(where)
         assert not frozenset(hey).issuperset(haveyou)
         assert frozenset(buthey).issuperset(been)
     
-    def test_ordered_mapping_views(self, dirname):
+    def test_chainmap_shallow_clone(self, arbitrary, fsdata, environment):
+        """ Shallow clone membership check """
+        from clu.dicts import ChainMap
+        from clu.predicates import try_items
+        
+        chain0 = ChainMap(arbitrary, fsdata, environment)
+        
+        chain1 = chain0.clone()
+        assert len(chain0) == len(chain1)
+        
+        for key in chain0.keys():
+            assert key in chain0
+            assert key in chain1
+            
+            # N.B. SLOW AS FUCK:
+            assert key in chain0.flatten()
+            
+            assert try_items(key, *chain0.maps, default=None) == try_items(key, *chain1.maps, default=None)
+            assert try_items(key, *chain0.maps, default=None) == chain0[key]
+            assert try_items(key, *chain0.maps, default=None) == chain1[key]
+    
+    def test_chainmap_deep_clone(self, arbitrary, fsdata, environment):
+        """ Deep clone membership check """
+        from clu.dicts import ChainMap
+        from clu.predicates import try_items
+        
+        chain0 = ChainMap(arbitrary, fsdata, environment)
+        
+        chainX = chain0.clone(deep=True)
+        assert len(chain0) == len(chainX)
+        
+        for key in chain0.keys():
+            assert key in chain0
+            assert key in chainX
+            
+            # N.B. SLOW AS FUCK:
+            assert key in chain0.flatten()
+            
+            assert try_items(key, *chain0.maps, default=None) == try_items(key, *chainX.maps, default=None)
+            assert try_items(key, *chain0.maps, default=None) == chain0[key]
+            assert try_items(key, *chain0.maps, default=None) == chainX[key]
+    
+    def test_chainmap_equality_comparisons(self, arbitrary):
+        """ Equality comparisons across the board """
+        from clu.dicts import ChainMap
+        from clu.config.keymap import flatdict, Flat
+        
+        chain0 = ChainMap(arbitrary, Flat(flatdict()))
+        chain1 = chain0.clone()
+        chainX = chain0.clone(deep=True)
+        
+        assert chain0 == ChainMap(arbitrary, Flat(flatdict()))
+        assert chain0 == chain1
+        assert chain0 == chainX
+        assert chainX == chain1
+    
+    def test_chainmap_compatibilty_stdlib_collections_chainmap(self, arbitrary):
+        """ Compatibility checks with “collections.ChainMap” """
+        from clu.dicts import ChainMap, ChainRepr
+        from clu.config.keymap import flatdict, Flat
+        import collections
+        
+        chain0 = ChainMap(arbitrary, Flat(flatdict()))
+        chainO = collections.ChainMap(arbitrary, Flat(flatdict()))
+        
+        assert len(chain0) == len(chainO)
+        
+        for key in chain0.keys():
+            assert chain0[key] == chainO[key]
+        
+        chainZ = ChainMap(chainO)
+        
+        assert chainZ == chain0
+        assert chainZ == chainO
+        
+        repr_instance = ChainRepr()
+        
+        assert repr_instance.repr(chain0) == repr_instance.repr(chainO)
+    
+    def test_ordered_mapping_views(self, dirname, fsdata):
         """ The ordered mapping views are returned from “clu.fs.filesystem.Directory”
             mapping-view methods: “directory.items()”, “directory.keys()”, and
             “directory.values()”.
@@ -141,52 +225,49 @@ class TestDicts(object):
         from clu.fs.filesystem import Directory
         from clu.typology import ismapping, issequence
         
-        # READ-ONLY:
-        data = dirname.subdirectory('data')
-        
         # Ensure type:
         assert type(dirname) is Directory
-        assert type(data) is Directory
-        assert type(data.items()) is OrderedItemsView
-        assert type(data.keys()) is OrderedKeysView
-        assert type(data.values()) is OrderedValuesView
+        assert type(fsdata) is Directory
+        assert type(fsdata.items()) is OrderedItemsView
+        assert type(fsdata.keys()) is OrderedKeysView
+        assert type(fsdata.values()) is OrderedValuesView
         
         # Ensure it’s a mapping:
         assert ismapping(dirname)
-        assert ismapping(data)
+        assert ismapping(fsdata)
         
         # Ensure it’s a sequence:
-        assert issequence(data.items())
-        assert issequence(data.keys())
-        assert issequence(data.values())
+        assert issequence(fsdata.items())
+        assert issequence(fsdata.keys())
+        assert issequence(fsdata.values())
         
         # Ensure repr:
         assert repr(dirname).startswith('Directory')
-        assert repr(data).startswith('Directory')
-        assert repr(data.items()).startswith('OrderedItemsView')
-        assert repr(data.keys()).startswith('OrderedKeysView')
-        assert repr(data.values()).startswith('OrderedValuesView')
+        assert repr(fsdata).startswith('Directory')
+        assert repr(fsdata.items()).startswith('OrderedItemsView')
+        assert repr(fsdata.keys()).startswith('OrderedKeysView')
+        assert repr(fsdata.values()).startswith('OrderedValuesView')
         
         # Redundant, but correct:
-        assert len(data.items()) == len(data.keys()) == len(data.values())
-        assert len(list(data.items())) == len(list(data.keys())) == len(list(data.values()))
-        assert len(data.items()) == len(list(data.items()))
-        assert len(data.keys()) == len(list(data.keys()))
-        assert len(data.values()) == len(list(data.values()))
+        assert len(fsdata.items()) == len(fsdata.keys()) == len(fsdata.values())
+        assert len(list(fsdata.items())) == len(list(fsdata.keys())) == len(list(fsdata.values()))
+        assert len(fsdata.items()) == len(list(fsdata.items()))
+        assert len(fsdata.keys()) == len(list(fsdata.keys()))
+        assert len(fsdata.values()) == len(list(fsdata.values()))
         
         # Nonexistent subdirectory:
-        assert len(data.subdirectory('wat').items()) == 0
-        assert len(data.subdirectory('wat').keys()) == 0
-        assert len(data.subdirectory('wat').values()) == 0
+        assert len(fsdata.subdirectory('wat').items()) == 0
+        assert len(fsdata.subdirectory('wat').keys()) == 0
+        assert len(fsdata.subdirectory('wat').values()) == 0
         
         # Real subdirectory with at least one item:
-        assert len(data.subdirectory('yodogg').items()) > 0
-        assert len(data.subdirectory('yodogg').keys()) > 0
-        assert len(data.subdirectory('yodogg').values()) > 0
+        assert len(fsdata.subdirectory('yodogg').items()) > 0
+        assert len(fsdata.subdirectory('yodogg').keys()) > 0
+        assert len(fsdata.subdirectory('yodogg').values()) > 0
         
         # Set properties:
-        k1 = data.subdirectory('yodogg').keys()
-        k2 = data.subdirectory('yodata').keys()
+        k1 = fsdata.subdirectory('yodogg').keys()
+        k2 = fsdata.subdirectory('yodata').keys()
         kU = k1 | k2
         assert type(kU) is set
         assert len(kU) == len(k1) + len(k2)
@@ -194,65 +275,8 @@ class TestDicts(object):
         assert kU.issuperset(k2)
         
         # Sequence properties:
-        keys = data.keys()
+        keys = fsdata.keys()
         for idx in range(len(keys)):
             assert keys[idx] == list(keys)[idx]
-            assert keys[idx] in data
-    
-    def test_dict_and_namespace_merge(self):
-        from clu.dicts import merge
-        from clu.typespace import Namespace
-        
-        dict_one = { 'compress_level' : 9,
-                           'optimize' : True,
-                             'format' : 'png' }
-        
-        dict_two = { 'yo' : 'dogg' }
-        
-        dict_three = { 'compress_level' : 10,
-                             'optimize' : True,
-                               'format' : 'jpg' }
-        
-        merged = merge(dict_one, dict_two, dict_three, yo='DOGG')
-        
-        # print("» Checking “merge(•) …”")
-        # print()
-        
-        assert merged == { 'compress_level' : 9,
-                                 'optimize' : True,
-                                   'format' : 'png',
-                                       'yo' : 'DOGG' }
-        
-        # print("» Checking “Namespace.operator+(•) …”")
-        # print()
-        
-        ns1 = Namespace(dict_one)
-        ns2 = Namespace(dict_two)
-        
-        merged = ns1 + ns2 + dict_three + Namespace(yo='DOGG')
-        
-        assert merged == { 'compress_level' : 9,
-                                 'optimize' : True,
-                                   'format' : 'png',
-                                       'yo' : 'dogg' }
-        
-        # print("» Checking “Namespace.operator+=(•) …”")
-        # print()
-        
-        merged = Namespace(dict_one)
-        ns2 = Namespace(dict_two)
-        
-        merged += ns2
-        merged += dict_three
-        merged += Namespace(yo='DOGG')
-        
-        assert merged == { 'compress_level' : 10,
-                                 'optimize' : True,
-                                   'format' : 'jpg',
-                                       'yo' : 'DOGG' }
-        
-        # print_separator()
-        # pprint(merged)
-        # print_separator()
-        # print()
+            assert keys[idx] in fsdata
     
\ No newline at end of file
