@@ -27,14 +27,15 @@ class TestImporting(object):
             
             assert not hasattr(overridden, 'targets')
             assert not hasattr(overridden, 'target_dicts')
+            assert hasattr(overridden, '_targets')
             
             with pytest.raises(AttributeError) as exc:
                 assert overridden.YODOGG
-            assert "has no attribute" in str(exc.value)
+            assert "access failure" in str(exc.value)
             
             with pytest.raises(AttributeError) as exc:
                 assert overridden.add_targets
-            assert "has no attribute" in str(exc.value)
+            assert "access failure" in str(exc.value)
         
         finally:
             Registry.unregister(overridden.appname,
